# Mopidy HTTP frontend

This web server is a part of the music server Mopidy. To learn more about Mopidy, please visit www.mopidy.com.

## WebSocket endpoint

Mopidy has a WebSocket endpoint at `/mopidy/ws/`. You can use this end point to access Mopidy's full API, and to get notified about events happening in Mopidy.

## Example

Here you can see events arriving from Mopidy in real time:

Nothing to see? Try playing a track using your MPD client.

## Documentation

For more information, please refer to the Mopidy documentation at docs.mopidy.com.